<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>PatientBar</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbar.ui" line="96"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbar.ui" line="135"/>
        <source>Name, Secondname - firstname</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PatientSelector</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientselector.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientselector.ui" line="20"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
<context>
    <name>Patients</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="39"/>
        <source>Search by Name</source>
        <translation>Chercher par nom</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="40"/>
        <source>Search by Firstname</source>
        <translation>Chercher par prénom</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="41"/>
        <source>Search by Name and Firstname</source>
        <translation>Chercher par nom et prénom</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="42"/>
        <source>Search by Date Of Birth</source>
        <translation>Chercher par date de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="44"/>
        <source>Type the name or second name of the patient</source>
        <translation>Saisissez le nom de naissance ou marital du patient</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="45"/>
        <source>Type the firstname of the patient</source>
        <translation>Saisissez le prénom du patient</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="46"/>
        <source>Type the name or second name followed by ; and the firstname</source>
        <translation>Saisissez le nom de naissance ou marital suivi du prénom du patient</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="47"/>
        <source>Type the date of birth (yyyy/MM/dd)</source>
        <translation>Saisissez la date de naissance (yyyy/MM/dd)</translation>
    </message>
</context>
<context>
    <name>Patients::IdentityPage</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="101"/>
        <source>Please enter the patient&apos;s identity.</source>
        <translation>Veuillez saisir l&apos;identité du patient.</translation>
    </message>
</context>
<context>
    <name>Patients::IdentityWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="201"/>
        <source>born on</source>
        <translation>né(e) le</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="215"/>
        <source>You must specify a birthname.</source>
        <translation>Vous devez spécifier un nom de naissance.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="216"/>
        <source>You can not create a patient without a birthname</source>
        <translation>Vous ne pouvez pas créer un patient sans nom de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="217"/>
        <source>No birthname</source>
        <translation>Pas de nom de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="221"/>
        <source>You must specify a firstname.</source>
        <translation>Vous devez spécifier un prénom.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="222"/>
        <source>You can not create a patient without a firstname</source>
        <translation>Vous ne pouvez pas créer un patient sans prénom</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="223"/>
        <source>No firstname</source>
        <translation>Pas de prénom</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="227"/>
        <source>You must specify a date of birth.</source>
        <translation>Vous devez spécifier une date de naissance.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="228"/>
        <source>You can not create a patient without a date of birth</source>
        <translation>Vous ne pouvez pas créer un patient sans date de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="229"/>
        <source>No date of birth</source>
        <translation>Pas de date de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="233"/>
        <source>You must specify a gender.</source>
        <translation>Vous devez spécifier un sexe.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="234"/>
        <source>You can not create a patient without a gender</source>
        <translation>Vous ne pouvez pas créer un patient sans sexe</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="235"/>
        <source>No gender</source>
        <translation>Pas de sexe</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="295"/>
        <source>Choose a photo</source>
        <translation>Choisissez une photographie</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::IdentityViewer</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="148"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="171"/>
        <source>Contact</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::IdentityWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="20"/>
        <source>Identity</source>
        <translation>Identité</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="26"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="54"/>
        <source>Click to add/change the photo</source>
        <translation>Cliquez pour ajouter/modifier la photographie</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="73"/>
        <source>Birth Name</source>
        <translation>Nom de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="83"/>
        <source>Second name</source>
        <translation>Nom marital</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="93"/>
        <source>Firstname</source>
        <translation>Prénom</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="103"/>
        <source>Gender</source>
        <translation>Sexe</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="113"/>
        <source>Date of birth</source>
        <translation>Date de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="123"/>
        <source>dd/MM/yyyy</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="136"/>
        <source>Adress</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="142"/>
        <source>Street</source>
        <translation>Rue</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="149"/>
        <source>City</source>
        <translation>Ville</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="159"/>
        <source>Zipcode</source>
        <translation>Code postal</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="169"/>
        <source>Country</source>
        <translation>Pays</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientActionHandler</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="149"/>
        <source>Fatal Error</source>
        <translation>Erreur fatale</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="149"/>
        <source>%1 : Unable to retreive patients menu.</source>
        <translation>%1 : Impossible de récupérer le menu patient.</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBase</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="322"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="330"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="336"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="346"/>
        <source>Please contact dev team.</source>
        <translation>Veuillez contacter l&apos;équipe de développement.</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBasePreferencesPage</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.cpp" line="67"/>
        <source>Patient database preferences</source>
        <translation>Préférences pour la base de données patients</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBasePreferencesWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="20"/>
        <source>Patient selector</source>
        <translation>Sélectionneur de patient</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="26"/>
        <source>Use color to differentiate genders</source>
        <translation>Différentier les sexes par des couleurs différentes</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="33"/>
        <source>Select newly created patients</source>
        <translation>Sélectionner les patients nouvellement créés</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="56"/>
        <source>Patient bar</source>
        <translation>Barre patient</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="62"/>
        <source>Background color</source>
        <translation>Couleur de fond</translation>
    </message>
</context>
<context>
    <name>Patients::PatientBasePlugin</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbaseplugin.cpp" line="106"/>
        <location filename="../../plugins/patientbaseplugin/patientbaseplugin.cpp" line="153"/>
        <source>Initializing patients database plugin...</source>
        <translation>Initialisation de la base de données patients...</translation>
    </message>
</context>
<context>
    <name>Patients::PatientCreatorWizard</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="59"/>
        <source>New Patient</source>
        <translation>Nouveau patient</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="73"/>
        <source>WARNING ! You don&apos;t saved this patient.</source>
        <translation>ATTENTION ! Vous n&apos;avez pas sauvegarder ce patient.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="74"/>
        <source>If you continue changes will be lost.
Do you really want to close this dialog ?</source>
        <translation>Si vous continuez, les changements seront perdus.
Voulez-vous réellement fermer ce dialogue ?</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="76"/>
        <source>Patient not saved</source>
        <translation>Patient non sauvegardé</translation>
    </message>
</context>
</TS>
